#
# spec file for package acl
#
# Copyright (c) 2022-2023 ZhuningOS
#


# Ring0 does not have system-user-bin/system-user-daemon
%bcond_without acl_tests

Name:           acl
%define lname	libacl1
Summary:        Commands for Manipulating POSIX Access Control Lists
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Filesystems
Version:        2.2.52
Release:        4.3.1
Url:            http://download.savannah.gnu.org/releases-noredirect/acl/

#Git-Web:	http://git.savannah.gnu.org/cgit/acl.git/
#Git-Clone:	git://git.sv.gnu.org/acl
# Source is generated by git-archive v2.2.52 so that the subsequent commits
# apply cleanly.
Source:         %name-%version.tar.bz2
Source2:        baselibs.conf
# http://savannah.nongnu.org/project/memberlist-gpgkeys.php?group=acl
Source3:        %name.keyring

# Upstream changes since v2.2.52
Patch1:         0001-Install-the-libraries-to-the-appropriate-directory.patch
Patch2:         0002-setfacl.1-fix-typo-inclu-de-include.patch
Patch3:         0003-test-fix-insufficient-quoting-of.patch
Patch4:         0004-Makefile-rename-configure.in-to-configure.ac.patch
Patch5:         0005-Bad-markup-in-acl.5-page.patch
Patch6:         0006-.gitignore-ignore-and-config.h.in.patch
Patch7:         0007-Use-autoreconf-rather-than-autoconf-to-regenerate-th.patch
Patch8:         0008-libacl-Make-sure-that-acl_from_text-always-sets-errn.patch
Patch9:         0009-libacl-fix-SIGSEGV-of-getfacl-e-on-overly-long-group.patch
Patch10:        0010-punt-debian-rpm-packaging-logic.patch
Patch11:        0011-move-gettext-logic-into-misc.h.patch
Patch12:        0012-test-make-running-parallel-out-of-tree-safe.patch
Patch13:        0013-modernize-build-system.patch
Patch14:        0014-po-regenerate-files-after-move.patch
Patch15:        0015-build-drop-aclincludedir-use-pkgincludedir.patch
Patch16:        0016-build-make-use-of-an-aux-dir-to-stow-away-helper-scr.patch
Patch17:        0017-build-ship-a-pkgconfig-file-for-libacl.patch
Patch18:        0018-read_acl_-comments-seq-rename-line-to-lineno.patch
Patch19:        0019-read_acl_-comments-seq-switch-to-next_line.patch
Patch20:        0020-telldir-return-value-and-seekdir-second-parameters-a.patch
Patch21:        0021-mark-libmisc-funcs-as-hidden-so-they-are-not-exporte.patch
Patch22:        0022-add-__acl_-prefixes-to-internal-symbols.patch
Patch23:        0023-cp.test-Check-permissions-of-the-right-file.patch
Patch24:        0024-libacl-acl_set_file-Remove-unnecesary-racy-check.patch
Patch25:        0025-fix-compilation-with-latest-xattr-git.patch
Patch26:        0026-getfacl-Fix-memory-leak.patch
Patch27:        0027-Fix-the-display-block-nesting-in-acl.5.patch
Patch28:        0028-setfacl-man-page-Minor-wording-improvements.patch
Patch29:        0029-getfacl-Fix-minor-resource-leak.patch
Patch30:        0030-Do-not-export-symbols-that-are-not-supposed-to-be-ex.patch
Patch31:        0031-walk_tree-mark-internal-variables-as-static.patch
Patch32:        0032-ignore-configure.lineno.patch
Patch33:	0001-test-Add-helper-library-to-fake-passwd-group-files.patch
Patch34:	0002-quote-escape-literal-backslashes.patch

# Local changes
Patch100:       0001-Use-OS-byteswapping-macros.patch
Patch101:       acl-2.2.52-tests.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-tools-mini
BuildRequires:  libattr-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
%if %{with acl_tests} && 0%{?suse_version} > 1320
BuildRequires:  system-user-bin
BuildRequires:  system-user-daemon
%endif
#BuildRequires:  gpg-offline
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
getfacl and setfacl commands for retrieving and setting POSIX access
control lists.

%package -n %lname
Summary:        A dynamic library for accessing POSIX Access Control Lists
# bug437293
Group:          System/Libraries
%ifarch ppc64
Obsoletes:      libacl-64bit
%endif
# Added for 12.1
Provides:       libacl = %version-%release
Obsoletes:      libacl < %version-%release

%description -n %lname
This package contains the libacl.so dynamic library which contains the
POSIX 1003.1e draft standard 17 functions for manipulating access
control lists.

%package -n libacl-devel
Summary:        Include Files and Libraries mandatory for Development
# the .so file references libattr.so.x, so require libattr-devel
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       glibc-devel
Requires:       libattr-devel
Provides:       acl-devel = %version
Obsoletes:      acl-devel < %version
# bug437293
%ifarch ppc64
Obsoletes:      libacl-devel-64bit
%endif
#

%description -n libacl-devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%setup -q -n acl-%version
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1

%patch100 -p1
%patch101 -p1

%build
chmod a+x po/update-potfiles
sh autogen.sh
export OPTIMIZER="%optflags -fPIC"
export DEBUG=-DNDEBUG
CFLAGS="%optflags"

%ifarch %ix86 i586
export CFLAGS="%optflags -D_FILE_OFFSET_BITS=64"
%endif

%configure \
	--prefix=/usr \
	--exec-prefix=/usr \
	--libdir=/%_lib \
	--libexecdir=/%_lib \
	--disable-static \
	--docdir=%_defaultdocdir/%name
make %{?_smp_mflags} V=1

%check
%if %{with acl_tests}
    if ./setfacl -m u:`id -u`:rwx .; then
        make check || (cat test-suite.log ; false)
    else
        echo '*** ACLs are probably not supported by the file system,' \
             'the test-suite will NOT run ***'
    fi
%endif

%install
%make_install
mkdir -p %buildroot/%_libdir
ln -sv /%_lib/$(readlink %buildroot/%_lib/lib%name.so) %buildroot/%_libdir/lib%name.so
rm -v %buildroot/%_lib/lib%name.{la,so}
# The library stays in /lib* but the pkgconfig file needs to go under /usr
mv -f %buildroot/%_lib/pkgconfig/ %buildroot/%_libdir
%find_lang %name

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -f %name.lang
%defattr(-,root,root)
%_bindir/chacl
%_bindir/getfacl
%_bindir/setfacl
%_defaultdocdir/acl/
%_mandir/man1/*.1*
%_mandir/man5/*.5*

%files -n libacl-devel
%defattr(-,root,root)
%_includedir/acl/
%_includedir/sys/acl.h
%_libdir/libacl.so
%_mandir/man3/*.3*
%_libdir/pkgconfig/libacl.pc

%files -n %lname
%defattr(755,root,root,755)
/%_lib/libacl.so.1*

%changelog
